/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2020-2024. All rights reserved.
 */

#ifndef DPC_IMPL_TYPE_RMEGOLFTLNEGEOMETRY_H
#define DPC_IMPL_TYPE_RMEGOLFTLNEGEOMETRY_H

#include <cfloat>
#include <cmath>
#include "impl_type_float.h"
#include "impl_type_boolean.h"

namespace dpc {
struct RMEgoLftLnegeometry {
    ::Float c0_llne{ 0.0F };
    ::Float c1_llne{ 0.0F };
    ::Float c2_llne{ 0.0F };
    ::Float c3_llne{ 0.0F };
    ::Float start_rnge_llne{ 0.0F };
    ::Float end_rnge_llne{ 0.0F };
    ::Float probability_llne{ 0.0F };
    ::Boolean valid_llne{ false };

    static bool IsPlane()
    {
        return true;
    }


    using IsEnumerableTag = void;
    template<typename F>
    void enumerate(F& fun)
    {
        fun(c0_llne);
        fun(c1_llne);
        fun(c2_llne);
        fun(c3_llne);
        fun(start_rnge_llne);
        fun(end_rnge_llne);
        fun(probability_llne);
        fun(valid_llne);
    }

    template<typename F>
    void enumerate(F& fun) const
    {
        fun(c0_llne);
        fun(c1_llne);
        fun(c2_llne);
        fun(c3_llne);
        fun(start_rnge_llne);
        fun(end_rnge_llne);
        fun(probability_llne);
        fun(valid_llne);
    }

    template<typename F>
    void enumerate_internal(F& fun)
    {
        fun("c0_llne", c0_llne);
        fun("c1_llne", c1_llne);
        fun("c2_llne", c2_llne);
        fun("c3_llne", c3_llne);
        fun("start_rnge_llne", start_rnge_llne);
        fun("end_rnge_llne", end_rnge_llne);
        fun("probability_llne", probability_llne);
        fun("valid_llne", valid_llne);
    }

    template<typename F>
    void enumerate_internal(F& fun) const
    {
        fun("c0_llne", c0_llne);
        fun("c1_llne", c1_llne);
        fun("c2_llne", c2_llne);
        fun("c3_llne", c3_llne);
        fun("start_rnge_llne", start_rnge_llne);
        fun("end_rnge_llne", end_rnge_llne);
        fun("probability_llne", probability_llne);
        fun("valid_llne", valid_llne);
    }

    friend bool operator==(const ::dpc::RMEgoLftLnegeometry& lhs, const ::dpc::RMEgoLftLnegeometry& rhs) noexcept
    {
        return (fabs(static_cast<double>(lhs.c0_llne - rhs.c0_llne)) < DBL_EPSILON) && (fabs(static_cast<double>(lhs.c1_llne - rhs.c1_llne)) < DBL_EPSILON) && (fabs(static_cast<double>(lhs.c2_llne - rhs.c2_llne)) < DBL_EPSILON) && (fabs(static_cast<double>(lhs.c3_llne - rhs.c3_llne)) < DBL_EPSILON) && (fabs(static_cast<double>(lhs.start_rnge_llne - rhs.start_rnge_llne)) < DBL_EPSILON) && (fabs(static_cast<double>(lhs.end_rnge_llne - rhs.end_rnge_llne)) < DBL_EPSILON) && (fabs(static_cast<double>(lhs.probability_llne - rhs.probability_llne)) < DBL_EPSILON) && (lhs.valid_llne == rhs.valid_llne);
    }
};
} // namespace dpc


#endif // DPC_IMPL_TYPE_RMEGOLFTLNEGEOMETRY_H
